@@ -1,7 +1,7 @@
 /*
  * BSD LICENSE
  *
- * Copyright(c) 2014-2019 Intel Corporation. All rights reserved.
+ * Copyright(c) 2014-2020 Intel Corporation. All rights reserved.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -74,8 +74,7 @@ int pqos_alloc_fini(void);
  *
  * @return Operations status
  */
-int hw_alloc_assoc_set(const unsigned lcore,
-                       const unsigned class_id);
+int hw_alloc_assoc_set(const unsigned lcore, const unsigned class_id);
 
 /**
  * @brief Hardware interface to read association
@@ -87,8 +86,7 @@ int hw_alloc_assoc_set(const unsigned lcore,
  * @return Operations status
  * @retval PQOS_RETVAL_OK on success
  */
-int hw_alloc_assoc_get(const unsigned lcore,
-                       unsigned *class_id);
+int hw_alloc_assoc_get(const unsigned lcore, unsigned *class_id);
 
 /**
  * @brief Hardware interface to assign first available
@@ -124,8 +122,7 @@ int hw_alloc_assign(const unsigned technology,
  *
  * @return Operations status
  */
-int hw_alloc_release(const unsigned *core_array,
-                     const unsigned core_num);
+int hw_alloc_release(const unsigned *core_array, const unsigned core_num);
 
 /**
  * @brief Hardware interface to reset configuration
@@ -258,6 +255,24 @@ int hw_mba_set(const unsigned mba_id,
                const struct pqos_mba *requested,
                struct pqos_mba *actual);
 
+/**
+ * @brief Hardware interface to set classes of service
+ *        defined by \a requested on \a mba_id
+ * @NOTE: This function is specific to AMD
+ *
+ * @param [in]  mba_id
+ * @param [in]  num_cos number of classes of service at \a ca
+ * @param [in]  requested table with class of service definitions
+ * @param [out] actual table with class of service definitions
+ *
+ * @return Operations status
+ * @retval PQOS_RETVAL_OK on success
+ */
+int hw_mba_set_amd(const unsigned mba_id,
+                   const unsigned num_cos,
+                   const struct pqos_mba *requested,
+                   struct pqos_mba *actual);
+
 /**
  * @brief Hardware interface to read MBA from \a mba_id
  *
@@ -275,6 +290,24 @@ int hw_mba_get(const unsigned mba_id,
                unsigned *num_cos,
                struct pqos_mba *mba_tab);
 
+/**
+ * @brief Hardware interface to read MBA from \a mba_id
+ * @NOTE: This function is specific to AMD
+ *
+ * @param [in]  mba_id MBA resource id
+ * @param [in]  max_num_cos maximum number of classes of service
+ *              that can be accommodated at \a mba_tab
+ * @param [out] num_cos number of classes of service read into \a mba_tab
+ * @param [out] mba_tab table with read classes of service
+ *
+ * @return Operations status
+ * @retval PQOS_RETVAL_OK on success
+ */
+int hw_mba_get_amd(const unsigned mba_id,
+                   const unsigned max_num_cos,
+                   unsigned *num_cos,
+                   struct pqos_mba *mba_tab);
+
 #ifdef __cplusplus
 }
 #endif
