@@ -1,7 +1,7 @@
 /*
  * BSD LICENSE
  *
- * Copyright(c) 2014-2019 Intel Corporation. All rights reserved.
+ * Copyright(c) 2014-2020 Intel Corporation. All rights reserved.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -99,6 +99,13 @@ void _pqos_api_unlock(void);
  */
 int _pqos_check_init(const int expect);
 
+/**
+ * @brief Internal API to retrie PQoS interface
+ *
+ * @return PQoS interface
+ */
+enum pqos_interface _pqos_iface(void);
+
 /**
  * @brief Internal API to retrie PQoS capabilities data
  *
